@@ -22,14 +22,13 @@
 #include "gui/osdwidget.h"
 
 // Qt
+#include <QIcon>
 #include <QGraphicsLinearLayout>
 #include <QPainter>
 #include <QTimer>
 #include <QLabel>
 
 // KDE
-#include <KIcon>
-#include <KDialog>
 #include <KWindowSystem>
 #include <Plasma/Svg>
 #include <Plasma/Label>
@@ -160,11 +159,11 @@ void OSDWidget::themeUpdated()
         m_volumeLowPixmap = svgIcon.pixmap("audio-volume-low");
         m_volumeMutedPixmap = svgIcon.pixmap("audio-volume-muted");
     } else {
-        iconSize = QSize(KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium);
-        m_volumeHighPixmap = KIcon( QLatin1String( "audio-volume-high" )).pixmap(iconSize);
-        m_volumeMediumPixmap = KIcon( QLatin1String( "audio-volume-medium" )).pixmap(iconSize);
-        m_volumeLowPixmap = KIcon( QLatin1String( "audio-volume-low" )).pixmap(iconSize);
-        m_volumeMutedPixmap = KIcon( QLatin1String( "audio-volume-muted" )).pixmap(iconSize);
+        iconSize = QSize(IconSize(KIconLoader::Toolbar), IconSize(KIconLoader::Toolbar));
+        m_volumeHighPixmap = QIcon::fromTheme( QLatin1String( "audio-volume-high" )).pixmap(iconSize);
+        m_volumeMediumPixmap = QIcon::fromTheme( QLatin1String( "audio-volume-medium" )).pixmap(iconSize);
+        m_volumeLowPixmap = QIcon::fromTheme( QLatin1String( "audio-volume-low" )).pixmap(iconSize);
+        m_volumeMutedPixmap = QIcon::fromTheme( QLatin1String( "audio-volume-muted" )).pixmap(iconSize);
     }
 
     m_iconLabel->nativeWidget()->setPixmap(m_volumeHighPixmap);
@@ -193,7 +192,7 @@ void OSDWidget::themeUpdated()
  */
 void OSDWidget::setCurrentVolume(int volumeLevel, bool muted)
 {
-//    kDebug() << "Meter is visible: " << m_meter->isVisible();
+//    qCDebug(KMIX_LOG) << "Meter is visible: " << m_meter->isVisible();
 
     if ( muted )
     {
@@ -217,4 +216,3 @@ void OSDWidget::setCurrentVolume(int volumeLevel, bool muted)
     m_volumeLabel->setText(QString::number(volumeLevel) + " %"); // if you change the text, please adjust textSize in themeUpdated()
 }
 
-#include "osdwidget.moc"
